from django import template

register = template.Library()


@register.inclusion_tag('maploom/_maploom_map.html')
def maploom_html(options=None):
    """
    Maploom html template tag.
    """
    return dict()


@register.inclusion_tag('maploom/_maploom_js.html')
def maploom_js(options=None):
    """
    Maploom js template tag.
    """
    return dict()



from django.conf.urls import patterns, url

urlpatterns = patterns('',
                       url(r'^maploom/maps/new', 'geonode.maps.views.new_map', {'template': 'maps/maploom.html'},
                           name='maploom-map-new'),
                       url(r'^maploom/maps/(?P<mapid>\d+)/view', 'geonode.maps.views.map_view',
                           {'template': 'maps/maploom.html'}, name='maploom-map-view'),)



import os
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

setup(
    name='django-maploom',
    version='1.2.7',
    author='LMN Solutions',
    author_email='geoshape.org@gmail.com',
    url='https://github.com/ROGUE-JCTD/django-maploom',
    download_url="https://github.com/ROGUE-JCTD/django-maploom",
    description="Use MapLoom in your django projects.",
    long_description=open(os.path.join(here, 'README.md')).read(),
    license='See LICENSE file.',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    classifiers=['Topic :: Utilities',
                 'Natural Language :: English',
                 'Operating System :: OS Independent',
                 'Intended Audience :: Developers',
                 'Environment :: Web Environment',
                 'Framework :: Django',
                 'Development Status :: 1 - Planning',
                 'Programming Language :: Python :: 2.7'],
)
